==> igniteui-react-core-18.5.2-beta.0.tgz: package/esm5/lib/WebInputBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebComponentValueChangedEventArgsDescriptionMetadata } from "./WebComponentValueChangedEventArgsDescriptionMetadata";
import { VoidEventArgsDescriptionMetadata } from "./VoidEventArgsDescriptionMetadata";
/**
 * @hidden
 */
var WebInputBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebInputBaseDescriptionMetadata, _super);
    function WebInputBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebInputBaseDescriptionMetadata.b = function (a) {
        if (WebInputBaseDescriptionMetadata.a == null) {
            WebInputBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebInputBaseDescriptionMetadata.c(WebInputBaseDescriptionMetadata.a);
        }
        if (a.k(WebInputBaseDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebInputBaseDescriptionMetadata.a);
        WebComponentValueChangedEventArgsDescriptionMetadata.d(a);
        VoidEventArgsDescriptionMetadata.d(a);
    };
    WebInputBaseDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:InputBase");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Outlined", "Boolean");
        a.item("ReadOnly", "Boolean");
        a.item("Placeholder", "String");
        a.item("Label", "String");
        a.item("Size", "ExportedType:string:SizableComponentSize");
        a.item("Size@names", "Large;Small;Medium");
        a.item("Disabled", "Boolean");
        a.item("Required", "Boolean");
        a.item("Invalid", "Boolean");
        a.item("InputOcurredRef", "EventRef::inputOcurred");
        a.item("FocusRef", "EventRef::focus");
        a.item("BlurRef", "EventRef::blur");
    };
    WebInputBaseDescriptionMetadata.d = function (a) {
        WebInputBaseDescriptionMetadata.b(a);
        a.ac("WebInputBase", WebInputBaseDescriptionMetadata.a);
    };
    WebInputBaseDescriptionMetadata.$t = markType(WebInputBaseDescriptionMetadata, 'WebInputBaseDescriptionMetadata');
    WebInputBaseDescriptionMetadata.a = null;
    return WebInputBaseDescriptionMetadata;
}(Base));
export { WebInputBaseDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.0.tgz: package/esm5/lib/WebInputBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebComponentValueChangedEventArgsDescriptionMetadata } from "./WebComponentValueChangedEventArgsDescriptionMetadata";
import { VoidEventArgsDescriptionMetadata } from "./VoidEventArgsDescriptionMetadata";
/**
 * @hidden
 */
var WebInputBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebInputBaseDescriptionMetadata, _super);
    function WebInputBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebInputBaseDescriptionMetadata.b = function (a) {
        if (WebInputBaseDescriptionMetadata.a == null) {
            WebInputBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebInputBaseDescriptionMetadata.c(WebInputBaseDescriptionMetadata.a);
        }
        if (a.k(WebInputBaseDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebInputBaseDescriptionMetadata.a);
        WebComponentValueChangedEventArgsDescriptionMetadata.d(a);
        VoidEventArgsDescriptionMetadata.d(a);
    };
    WebInputBaseDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:InputBase");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Outlined", "Boolean");
        a.item("ReadOnly", "Boolean");
        a.item("Placeholder", "String");
        a.item("Label", "String");
        a.item("Disabled", "Boolean");
        a.item("Required", "Boolean");
        a.item("Name", "String");
        a.item("Invalid", "Boolean");
        a.item("InputOcurredRef", "EventRef::inputOcurred");
        a.item("FocusRef", "EventRef::focus");
        a.item("BlurRef", "EventRef::blur");
    };
    WebInputBaseDescriptionMetadata.d = function (a) {
        WebInputBaseDescriptionMetadata.b(a);
        a.ad("WebInputBase", WebInputBaseDescriptionMetadata.a);
    };
    WebInputBaseDescriptionMetadata.$t = markType(WebInputBaseDescriptionMetadata, 'WebInputBaseDescriptionMetadata');
    WebInputBaseDescriptionMetadata.a = null;
    return WebInputBaseDescriptionMetadata;
}(Base));
export { WebInputBaseDescriptionMetadata };
